Calculate a design-based index with bootstrapped standard errors
Arguments
- species
Species common name or number
- ssid
Survey series ID
- reps
Number of bootstrap samples. Set to
0to skip the bootstrapping and only report design-based variance estimates.- data
Optional output from a call to
get_all_survey_sets(). By default, this function will callget_all_survey_sets()for the given species, but this requires access to the GFBio database, and will also be slower if you've already cached the data.